<?php
/**
 * Template Name: Script d'importation
 * @package WordPress
 * @subpackage Twenty_Twelve
 *
 * Script name: guppy-export.php
 * Copyright 2013 Nicolas Baudet <nico.baudet@gmail.com>
 * date 2013.01.06
 *
 * LICENSE
 * =======
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer ou le
 * modifier suivant les termes de la GNU General Public License telle que
 * publie par la Free Software Foundation ; soit la version 3 de la licence,
 * soit ( votre gr) toute version ultrieure.
 * 
 * Ce programme est distribu dans l'espoir qu'il sera utile, mais SANS AUCUNE
 * GARANTIE ; pas mme la garantie implicite de COMMERCIABILISABILIT ni
 * d'ADQUATION  UN OBJECTIF PARTICULIER. Consultez la GNU General Public
 * License pour plus de dtails.
 * 
 * Vous devez avoir reu une copie de la GNU General Public License en mme
 * temps que ce programme ; si ce n'est pas le cas, consultez
 * <http://www.gnu.org/licenses>
 * 
 * =======
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * LISEZ-MOI
 * =========
 * Description: Script permettant d'exporter un site sous GuppY vers une base
 * de donnes WordPress.
 * 
 * Prend en charge :
 * - les articles
 * - les pages statiques
 * - les prfrences du site
 *
 * POUR UTILISER, complter la partie configuration ci-dessous, COPIEZ le
 * dossier "data" de GuppY sur votre serveur. Notez son emplacement et crivez-le
 * dans la variable $guppy_dir plus bas.
 * Copiez ce script dans le dossier "page-templates" du thme twenty-twelve. Cela
 * va rajouter un template  ceux dj disponibles grce  ce thme.
 * Crez les mmes catgories sur votre WordPress que dans votre Guppy et relevez
 * leurs IDs respectifs.
 * Dans votre WordPress, crez une page "Script d'importation" et donnez-lui
 * ce template.
 * En appelant cette nouvelle page depuis la partie publique du site, vous allez
 * excuter le script et insrer tous vos anciens articles GuppY dans votre
 * WordPress.
 *
 * Remarques :
 * - Du fait des en-ttes PHP non-conformes des fichiers GuppY, il faut
 *   modifier votre fichier php.ini, et passer (temporairement) votre
 *   variable 'short_open_tag' en "On". Cette opration ne devrait pas se
 *   faire sur un serveur en production. Redmarrez votre serveur Apache
 *   pour que la modification prenne effet. (dfaut : Off)
 * - Il faut aussi modifier max_execution_time dans php.ini pour permettre
 *   au script le temps de s'excuter pleinement si vous avez beaucoup
 *   d'articles  importer. N'hsitez pas  mettre >= 500 (dfaut : 30 secondes).
 *   Ces lenteurs apparaissent apparement sur certains serveurs Wamp.
 * - Dsactivez votre antivirus si vous travaillez en local. Cela va acclrer
 *   grandement le processus d'importation si vous avez beaucoup d'articles.
 *
 */

/* =======================================================================*/
// CONFIGURATION
/* =======================================================================*/
// ID WordPress de l'auteur vers lequel les posts seront transfrs
$num_auteur = 3;

// Votre fuseau horaire
$fuseau = '+1'; // Ex : '0' ou '-5'

// Localisation d'une copie du dossier 'data' de GuppY
$guppy_dir = "wp-content/themes/data";

// Catgories des articles GuppY que l'on veut transfrer vers WordPress
$cat_guppy = array( 'foo',
                    'bar',
                    'etc...');

// Les ID des catgories correspondantes dans WordPress
// Si la catgorie de GuppY ne doit pas tre importe, mettre 0.
$cat_wp = array(1,
		2,
                3);

/* =======================================================================*/
// TEST DE LA CONFIGURATION
/* =======================================================================*/
// pas ncessaire ici.

/* =======================================================================*/
// FONCTIONS
/* =======================================================================*/
/**
 * dateG2WP renvoie une date au format WordPress depuis une date au format
 * GuppY.
 * @param $datein (String) : la date du post au format GuppY : YmdHi
 */
function dateG2WP($datein){
	$jour = substr($datein,6,2);
	$mois = substr($datein,4,2);
	$annee = substr($datein,0,4);
	$heure = substr($datein,8,2);
	$minute = substr($datein,10,2);

	return $annee.'-'.$mois.'-'.$jour.' '.$heure.':'.$minute.':00';
}

/**
 * dateG2WPGMT renvoie une date au format WordPress (GMT) depuis une date
 * au format GuppY
 * @param $datein (String) : la date du post au format Guppy : YmdHi
 */
function dateG2WPGMT($datein){
	$jour = substr($datein,6,2);
	$mois = substr($datein,4,2);
	$annee = substr($datein,0,4);
	$heure = substr($datein,8,2);
	$minute = substr($datein,10,2);
	
	if(substr($fuseau, 0, 1) == '+'){
		$heure -= substr($fuseau, 1, 1);
	}
	elseif(substr($fuseau, 0, 1) == '-'){
		$heure += substr($fuseau, 1, 1);
	}
	else{
		// Le fuseau horaire est cens tre GMT
	}
	
	return $annee.'-'.$mois.'-'.$jour.' '.$heure.':'.$minute.':00';
}

/* =======================================================================*/
// DEBUT TEMPLATE WORDPRESS
/* =======================================================================*/
get_header(); ?>
<?php
	/* Les posts de GuppY sont enregistrs dans des fichiers encods en ISO-8859-1.
	 * les posts WP s'affichent dans des pages en UTF-8. Donc si on veut afficher
	 * le contenu des posts de manire lisible quand on teste, il faut dcommenter
	 * la ligne suivante :
	 */
	header('Content-Type: text/html; charset=iso-8859-1');
?>

	<div id="primary" class="site-content">
		<div id="content" role="main">

			<?php while ( have_posts() ) : the_post(); ?>
				<?php get_template_part( 'content', 'page' ); ?>
				<?php comments_template( '', true ); ?>
				
				
				<?php
				/* =======================================================================*/
				// SCRIPT
				/* =======================================================================*/
				// on boucle sur chaque fichier pour en savoir le type
				echo "dbut du script !<br>";
				
				// rcupration des fichiers contenant un article
				$files = glob($guppy_dir.'/{doc}*.{inc}', GLOB_BRACE);
				
				// Pour limiter le script  100 fichiers, dcommentez les lignes suivantes
				//$cpt = 0;
				
				// Pour tous les articles
				foreach($files as $file){
					//$cpt++;
					//if($cpt == 100)
						//return;
					include $file;
					
					// S'ils sont de type article, et qu'ils sont actifs
					if($type == 'ar' && $status == 'a'){
						/**
						 * Affichage du rsultat aprs le texte de la page
						 * Remarque : l'affichage peut tre inatendu  cause de diffrences
						 * d'encodage. Cela ne se rpercute normalement pas dans la BD.
						 */
						/*echo 	'type : '.$type.'<br>'.
								'ID : '.$fileid.'<br>'.
								'Statut : '.$status.'<br>'.
								'Cr le : '.$creadate.'<br>'.
								'Modifi le : '.$moddate.'<br>'.
								//$author.'<br>'.
								//$email.'<br>'.
								'<h2>'.$fieldb1.'</h2><br>'.
								//$fielda2.'<br>'.
								'dans la catgorie '.$fielda1.'<br>'.
								//$fieldb2.'<br>'.
								'contenu : '.$fieldc1.'<br>';
								/*$fieldc2.'<br>'.
								$fieldd1.'<br>'.
								$fieldd2.'<br>'.
								$fieldweb.'<br>'.
								$fieldmail.'<hr>';*/
						
						/**
						 * Conversion des contenus des posts pour WordPress
						 */
						$post_content  = iconv('MS-ANSI', 'UTF-8', $fieldc1);
						$post_title    = iconv('MS-ANSI', 'UTF-8', $fieldb1);
						$post_category = iconv('MS-ANSI', 'UTF-8', $fielda1);
						
						
						/**
						 * Cration du post WordPress
						 */
						$post = array(
							'ID'             =>  0,  //Are you updating an existing post?
							'comment_status' => 'closed', // 'closed' means no comments.
							'ping_status'    => 'open', // 'closed' means pingbacks or trackbacks turned off
							'post_author'    => $num_auteur, //The user ID number of the author.
							//'post_category'  => [ array(<category id>, <...>) ] //post_category no longer exists, try wp_set_post_terms() for setting a post's categories
							'post_content'   => $post_content, //The full text of the post.
							'post_date'      => dateG2WP($creadate), //The time post was made.
							'post_date_gmt'  => dateG2WPGMT($creadate), //The time post was made, in GMT.
							//'post_excerpt'   => [ <an excerpt> ] //For all your post excerpt needs.
							//'post_name'      => $fieldb1, // The name (slug) for your post
							//'post_status'    => [ 'draft' | 'publish' | 'pending'| 'future' | 'private' | custom registered status ] //Set the status of the new post.
							'post_status'    => ($status == 'a') ? 'publish' : 'trash',
							'post_title'     => $post_title, //The title of your post.
							'post_type'      => 'post' //You may want to insert a regular post, page, link, a menu item or some custom post type
							//'tags_input'     => [ '<tag>, <tag>, <...>' ] //For tags.
							//'to_ping'        => [ ? ] //?
							//'tax_input'      => [ array( 'taxonomy_name' => array( 'term', 'term2', 'term3' ) ) ] // support for custom taxonomies. 
						);
						
						// Insertion du post cr
						$post_id = wp_insert_post($post);
						echo '<br>Post ID : '.$post_id;
						
						// Rajout de la catgorie (ne supporte qu'une catgorie par article)
						$pos = array_search($post_category, $cat_guppy);
						$cat_val = $cat_wp[$pos];
						$funcResults = wp_set_post_terms($post_id, $cat_val, 'category');
						
					} // if $type == 'ar'
					
				} // foreach $file
				
				// Articles que l'on jette ($cat_wp = 0)
				// Traitements particuliers [switch case]
				// Traitement par dfaut comme dernier case
                                
                                echo "<br>fin du script.";
				?>
				
			<?php endwhile; // end of the loop. ?>
			
		</div><!-- #content -->
	</div><!-- #primary -->

<?php get_footer(); ?>